==> nextcloud-app-tasks-0.9.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/ru.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Задачи",
    "Due yesterday" : "Вчера",
    "Due today" : "Сегодня",
    "Due tomorrow" : "Завтра",
    "Due on" : "Срок",
    "Started yesterday" : "Начато вчера",
    "Starts today" : "Начнется сегодня",
    "Starts tomorrow" : "Начнется завтра",
    "Started on" : "Начато",
    "Starts on" : "Начинается",
    "[Remind me yesterday at ]HH:mm" : "[Напомнить мне вчера в ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Напомнить мне сегодня в ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Напомнить мне завтра в  ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Напомнить мне ]DD MMM, YYYY,[ в ]HH:mm",
    "Yesterday" : "Вчера",
    "Today" : "Сегодня",
    "Tomorrow" : "Завтра",
    "in %s" : "в %s",
    "%s ago" : "%s назад",
    "seconds" : "секунд",
    "a minute" : "минуту",
    "%d minutes" : "%d минут",
    "an hour" : "час",
    "%d hours" : "%d часов",
    "a day" : "день",
    "%d days" : "%d дней",
    "a month" : "месяц",
    "%d months" : "%d месяцев",
    "a year" : "год",
    "%d years" : "%d лет",
    "week" : "неделя",
    "weeks" : "недель",
    "day" : "день",
    "days" : "дней",
    "hour" : "час",
    "hours" : "часов",
    "minute" : "минуту",
    "minutes" : "минут",
    "second" : "секунду",
    "before beginning" : "до начала",
    "after beginning" : "после начала",
    "before end" : "перед концом",
    "after end" : "после конца",
    "Comment" : "Коментарий",
    "Add a comment" : "Добавить комментарий",
    "This will delete the Calendar \"%s\" and all of its entries." : "Это действие удалит Календарь \"%s\" и всё его содержимое.",
    "The name \"%s\" is already used." : "Имя \"%s\" уже используется.",
    "An empty name is not allowed." : "Пустые имена не допускаются.",
    "Hidden" : "Скрыто",
    "Visible" : "Видимо",
    "Automatic" : "Автоматически",
    "Sunday" : "Воскресенье",
    "Monday" : "Понедельник",
    "Tuesday" : "Вторник",
    "Wednesday" : "Среда",
    "Thursday" : "Четверг",
    "Friday" : "Пятница",
    "Saturday" : "Суббота",
    "Add an important item in \"%s\"..." : "Добавить важный элемент в \"%s\"...",
    "Add an item due today in \"%s\"..." : "Добавить элемент сегодня в \"%s\"...",
    "Add an item in \"%s\"..." : "Добавить элемент в \"%s\"...",
    "Add a current item in \"%s\"..." : "Добавить текущий элемент в \"%s\"...",
    "Add a subtask to \"%s\"..." : "Добавить подзадачу в \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Завершенное Задание","%n Завершенных Задания","%n Завершенных Заданий","%n Завершенных Заданий"],
    "Hours" : "Часы",
    "Minutes" : "Минуты",
    "Set due date" : "Установить срок исполнения",
    "%s %% completed" : "%s %% завершено",
    "priority %s: " : "приоритет %s:",
    "high" : "высокий",
    "medium" : "средний",
    "low" : "низкий",
    "no priority assigned" : "нет приоритета",
    "Remind me" : "Напомнить мне",
    "at the end" : "в конце",
    "at the beginning" : "в начале",
    "Set start date" : "Установить начальную дату",
    "{calendar} shared by {owner}" : "{calendar} опубликован пользователем {owner}",
    "Unnamed" : "Не названный",
    "Important" : "Важный",
    "Week" : "Неделя",
    "All" : "Все",
    "Current" : "Текущие",
    "Completed" : "Завершённые",
    "Delete" : "Удалить",
    "Cancel" : "Отмена",
    "Edit" : "Редактировать",
    "Link" : "Ссылка",
    "Download" : "Скачать",
    "Save" : "Сохранить",
    "Add List..." : "Добавить Список...",
    "New List" : "Новый список",
    "Settings" : "Настройки",
    "Start of week" : "Начало недели",
    "Visibility of Smart Collections" : "Доступность Умных Коллекций",
    "Change sort order" : "Изменить порядок сортировки",
    "Default" : "По умолчанию",
    "Due date" : "Сделать к дате",
    "Start date" : "Дата начала",
    "Priority" : "Приоритет",
    "Alphabetically" : "По алфавиту",
    "Manually" : "Вручную",
    "Load remaining completed tasks." : "Загрузить оставшиеся завершённые задачи.",
    "All day" : "Весь день",
    "(New category)" : "(Новая категория)",
    "Select categories..." : "Выбрать категории...",
    "Loading the task..." : "Загрузка задачи...",
    "Task not found!" : "Задача не найдена!",
    "add a subtask to" : "добавить подзадачу в"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-app-tasks-0.9.6-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/ru.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Задачи",
    "Due yesterday" : "Вчера",
    "Due today" : "Сегодня",
    "Due tomorrow" : "Завтра",
    "Due on" : "Срок",
    "Started yesterday" : "Начато вчера",
    "Starts today" : "Начнется сегодня",
    "Starts tomorrow" : "Начнется завтра",
    "Started on" : "Начато",
    "Starts on" : "Начинается",
    "[Remind me yesterday at ]HH:mm" : "[Напомнить вчера в ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Напомнить сегодня в ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Напомнить завтра в  ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Напомнить мне ]DD MMM, YYYY,[ в ]HH:mm",
    "Yesterday" : "Вчера",
    "Today" : "Сегодня",
    "Tomorrow" : "Завтра",
    "in %s" : "в %s",
    "%s ago" : "%s назад",
    "seconds" : "секунд",
    "a minute" : "минуту",
    "%d minutes" : "%d минут",
    "an hour" : "час",
    "%d hours" : "%d часов",
    "a day" : "день",
    "%d days" : "%d дней",
    "a month" : "месяц",
    "%d months" : "%d месяцев",
    "a year" : "год",
    "%d years" : "%d лет",
    "week" : "неделя",
    "weeks" : "недель",
    "day" : "день",
    "days" : "дней",
    "hour" : "час",
    "hours" : "часов",
    "minute" : "минуту",
    "minutes" : "минут",
    "second" : "секунду",
    "before beginning" : "до начала",
    "after beginning" : "после начала",
    "before end" : "до окончания",
    "after end" : "после окончания",
    "Comment" : "Коментарий",
    "Add a comment" : "Добавить комментарий",
    "This will delete the Calendar \"%s\" and all of its entries." : "Это действие удалит календарь «%s» и всё его содержимое.",
    "The name \"%s\" is already used." : "Имя \"%s\" уже используется.",
    "An empty name is not allowed." : "Пустые имена не допускаются.",
    "Hidden" : "Скрывать",
    "Visible" : "Показывать",
    "Automatic" : "Автоматически",
    "Sunday" : "Воскресенье",
    "Monday" : "Понедельник",
    "Tuesday" : "Вторник",
    "Wednesday" : "Среда",
    "Thursday" : "Четверг",
    "Friday" : "Пятница",
    "Saturday" : "Суббота",
    "Add an important item in \"%s\"..." : "Добавить важный элемент в \"%s\"...",
    "Add an item due today in \"%s\"..." : "Добавить элемент сегодня в \"%s\"...",
    "Add an item in \"%s\"..." : "Добавить элемент в \"%s\"...",
    "Add a current item in \"%s\"..." : "Добавить текущий элемент в «%s»...",
    "Add a subtask to \"%s\"..." : "Добавить подзадачу в \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n завершённая задача","%n завершённых задачи","%n завершённых задач","%n завершённых задач"],
    "Hours" : "Часы",
    "Minutes" : "Минуты",
    "Set due date" : "Установить срок исполнения",
    "%s %% completed" : "%s %% завершено",
    "priority %s: " : "приоритет %s:",
    "high" : "высокий",
    "medium" : "средний",
    "low" : "низкий",
    "no priority assigned" : "приоритет не задан",
    "Remind me" : "Напомнить мне",
    "at the end" : "в конце",
    "at the beginning" : "в начале",
    "Set start date" : "Установить начальную дату",
    "{calendar} shared by {owner}" : "{calendar} опубликован пользователем {owner}",
    "Unnamed" : "Не названный",
    "Important" : "Важный",
    "Week" : "Неделя",
    "All" : "Все",
    "Current" : "Текущие",
    "Completed" : "Завершённые",
    "Delete" : "Удалить",
    "Cancel" : "Отмена",
    "Edit" : "Редактировать",
    "Link" : "Ссылка",
    "Download" : "Скачать",
    "Save" : "Сохранить",
    "Add List..." : "Добавить Список...",
    "New List" : "Новый список",
    "Settings" : "Настройки",
    "Start of week" : "Начало недели",
    "Visibility of Smart Collections" : "Доступность Умных Коллекций",
    "Change sort order" : "Изменить порядок сортировки",
    "Default" : "По умолчанию",
    "Due date" : "Сделать к дате",
    "Start date" : "Дата начала",
    "Priority" : "Приоритет",
    "Alphabetically" : "По алфавиту",
    "Manually" : "Вручную",
    "Load remaining completed tasks." : "Загрузить оставшиеся завершённые задачи.",
    "Task is completed" : "Задача завершена",
    "All day" : "Весь день",
    "(New category)" : "(Новая категория)",
    "Select categories..." : "Выбрать категории...",
    "Loading the task..." : "Загрузка задачи...",
    "Task not found!" : "Задача не найдена!",
    "add a subtask to" : "добавить подзадачу в",
    "Toggle subtasks" : "Поменять субзадачи",
    "Toggle completed subtasks" : "Поменять завершённые субзадачи"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
